Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetDirectionDifference ¶
GetDirectionDifference gets the difference between angels (in radians)
Important context: Radians range from 0 to 2PI
There should be a small difference between a value close to 2PI and a value close to 0 because if drawn on a circle they would be close.
Examples: 1PI - 1.5PI = 0.5PI, 1.75PI - 0.25PI = 0.5PI, 1.99PI - 0.01 = 0.02PI
Types ¶
type Vector ¶
type Vector struct {
A, B float64
}
func (*Vector) GetUnitVector ¶
Click to show internal directories.
Click to hide internal directories.